import func from "./func";
import { singleFileUpload, multiFileUpload } from '@/api/index.js'
import request from '@/util/request'

export default class upload {

  /**
   * 单个附件上传
   * @param file element file对象
   * @param fileType 1-证件，
                      2-合同，
                      3-发票，
                      4-其他，
                      5-贷后检查材料，
                      6-回单， 
                      7-财务报表 ，
                      8-授权书， 
                      9-承诺书 ，
                      10-协议，
                      11-网贷影像材料，
                      12-马消贷影像材料，
                      13-长安车贷影像材料，
                      14-云按揭材料，
                      15-保险材料，
                      16-ETC材料
                      17-烟叶资金结算签约影像资料
                      18-安全信息化管理系统影像
   * @param groupName 分组名称
   * @return {Promise<*>} 成功-uploadVo数组/失败-undifine
   */
  static async singleUpload(file, fileType, groupName) {
    if (func.isUndefined(file) || func.isUndefined(fileType) || func.isUndefined(groupName)) {
      return
    }
    let formData = new FormData()
    formData.append('file', file)
    formData.append('fileType', fileType)
    formData.append('groupName', groupName)
    return await singleFileUpload({}, formData).then(res => {
      if (res.data.code === 200) {
        return res.data.data
      }
    })
  }

  /**
   * 批量文件上传
   * @param uploadFiles element上传组件文件列表
   *  @param fileType 1-证件，
                      2-合同，
                      3-发票，
                      4-其他，
                      5-贷后检查材料，
                      6-回单， 
                      7-财务报表 ，
                      8-授权书， 
                      9-承诺书 ，
                      10-协议，
                      11-网贷影像材料，
                      12-马消贷影像材料，
                      13-长安车贷影像材料，
                      14-云按揭材料，
                      15-保险材料，
                      16-ETC材料
                      17-烟叶资金结算签约影像资料
                      18-安全信息化管理系统影像
   * @param groupName 分组名称
   * @return {Promise<*>} 成功-uploadVo数组/失败-undifine
   */
  static async multiUpload(uploadFiles, fileType, groupName) {
    if (func.isUndefined(uploadFiles) || func.isUndefined(fileType) || func.isUndefined(groupName)) {
      return
    }
    let formData = new FormData()
    if (uploadFiles.length > 0) {
      uploadFiles.forEach(item => {
        formData.append('files', item)
      })
    }
    formData.append('fileType', fileType)
    formData.append('groupName', groupName)
    return await multiFileUpload({}, formData).then(res => {
      if (res.data.code === 200) {
        return res.data.data
      }
    })
  }

  /**
   * 附件下载
   * @param file（文件）
   */
  static download(file) {
    let url = '/sis/api/security-desk' + file.url;
    if (file.encrypt) {
      url = url + '?encrypt=true'
    }
    request({
      url: url,
      method: 'get',
      headers: { 'Content-Type': 'multipart/form-data' },
      responseType: 'blob',
    }).then((res) => {
      let blob = new Blob([res.data]);
      let fileUrl = window.URL.createObjectURL(blob);
      let a = document.createElement('a');
      a.href = fileUrl;
      a.download = file.name;
      a.click();
      window.URL.revokeObjectURL(fileUrl);
    }).catch((err => {
      console.log(err);
    }))
  }

  static getImgPreviewFile(file, callback) {
    let url = '/sis/api/security-desk' + file.url;
    if (file.encrypt) {
      url = url + '?encrypt=true'
    }
    let contentType = 'multipart/form-data';
    switch (file.fileType) {
      case 'jpg':
      case 'jepg':
        contentType = 'image/jpeg';
        break;
      case 'png':
        contentType = 'image/png';
        break;
      case 'svg':
        contentType = 'image/svg+xml';
        break;
    }
    let headers = {
      'Content-Type': contentType
    }
    return request({
      url: url,
      method: 'get',
      headers: headers,
      responseType: 'blob',
    }).then((res) => {
      var fileReader = new FileReader();
      fileReader.onload = (e) => {
        callback(e.target.result);
      };
      fileReader.readAsDataURL(res.data);
    }).catch((err => {
      this.$message.error(err);
    }))
  }
}
